capture_trading_cmd

Function capture_trading_cmd 

pub fn capture_trading_cmd(message: TradingCommandMessage)
Captures a trading command for dispatch after the current endpoint handler returns.

Panics

Panics if no deferred trading command is being dispatched.