pub fn replace_data_cmd_sender(sender: Arc<dyn DataCommandSender>)Expand description
Replaces the global data command sender for the current thread.
pub fn replace_data_cmd_sender(sender: Arc<dyn DataCommandSender>)Replaces the global data command sender for the current thread.