pub fn replace_exec_cmd_sender(sender: Arc<dyn TradingCommandSender>)Expand description
Replaces the global trading command sender for the current thread.
pub fn replace_exec_cmd_sender(sender: Arc<dyn TradingCommandSender>)Replaces the global trading command sender for the current thread.