pub fn replace_time_event_sender(sender: Arc<dyn TimeEventSender>)Expand description
Replaces the global time event sender for the current thread.
pub fn replace_time_event_sender(sender: Arc<dyn TimeEventSender>)Replaces the global time event sender for the current thread.