TradingCommandSender

Trait TradingCommandSender 

pub trait TradingCommandSender {
    // Required method
    fn execute(&self, message: TradingCommandMessage);
}
Trait for trading command sending that can be implemented for both sync and async runners.

Required Methods

fn execute(&self, message: TradingCommandMessage)

Defers a trading command message.

  • Sync runners enqueue the message for synchronous execution.
  • Async runners send the message to a channel for asynchronous execution.

Runners dispatch each message to the direct endpoint it carries.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors