pub fn capture_trading_cmd(message: TradingCommandMessage)Expand description
Captures a trading command for dispatch after the current endpoint handler returns.
Panics
Panics if no deferred trading command is being dispatched.
pub fn capture_trading_cmd(message: TradingCommandMessage)Captures a trading command for dispatch after the current endpoint handler returns.
Panics if no deferred trading command is being dispatched.